Class: Aws::Evs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Evs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-evs/client.rb,
sig/client.rbs
Overview
An API client for Evs. To construct a client, you need to configure a :region and :credentials.
client = Aws::Evs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateEipToVlanResponseSuccess, _CreateEntitlementResponseSuccess, _CreateEnvironmentConnectorResponseSuccess, _CreateEnvironmentHostResponseSuccess, _CreateEnvironmentResponseSuccess, _DeleteEntitlementResponseSuccess, _DeleteEnvironmentConnectorResponseSuccess, _DeleteEnvironmentHostResponseSuccess, _DeleteEnvironmentResponseSuccess, _DisassociateEipFromVlanResponseSuccess, _GetDepotUrlResponseSuccess, _GetEnvironmentResponseSuccess, _GetVersionsResponseSuccess, _ListEnvironmentConnectorsResponseSuccess, _ListEnvironmentHostsResponseSuccess, _ListEnvironmentVlansResponseSuccess, _ListEnvironmentsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVmEntitlementsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateEnvironmentConnectorResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_eip_to_vlan(params = {}) ⇒ Types::AssociateEipToVlanResponse
Associates an Elastic IP address with a public HCX VLAN.
-
#create_entitlement(params = {}) ⇒ Types::CreateEntitlementResponse
Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
-
#create_environment_connector(params = {}) ⇒ Types::CreateEnvironmentConnectorResponse
Creates a connector for an Amazon EVS environment.
-
#create_environment_host(params = {}) ⇒ Types::CreateEnvironmentHostResponse
Creates an ESX host and adds it to an Amazon EVS environment.
-
#delete_entitlement(params = {}) ⇒ Types::DeleteEntitlementResponse
Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment.
-
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon EVS environment.
-
#delete_environment_connector(params = {}) ⇒ Types::DeleteEnvironmentConnectorResponse
Deletes a connector from an Amazon EVS environment.
-
#delete_environment_host(params = {}) ⇒ Types::DeleteEnvironmentHostResponse
Deletes a host from an Amazon EVS environment.
-
#disassociate_eip_from_vlan(params = {}) ⇒ Types::DisassociateEipFromVlanResponse
Disassociates an Elastic IP address from a public HCX VLAN.
-
#get_depot_url(params = {}) ⇒ Types::GetDepotUrlResponse
Returns a URL and authentication token for accessing the Amazon EVS Custom Addon depot.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns a description of the specified environment.
-
#get_versions(params = {}) ⇒ Types::GetVersionsResponse
Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS.
-
#list_environment_connectors(params = {}) ⇒ Types::ListEnvironmentConnectorsResponse
Lists the connectors within an environment.
-
#list_environment_hosts(params = {}) ⇒ Types::ListEnvironmentHostsResponse
List the hosts within an environment.
-
#list_environment_vlans(params = {}) ⇒ Types::ListEnvironmentVlansResponse
Lists environment VLANs that are associated with the specified environment.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for an Amazon EVS resource.
-
#list_vm_entitlements(params = {}) ⇒ Types::ListVmEntitlementsResponse
Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to an Amazon EVS resource with the specified
resourceArn. -
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from an Amazon EVS resource.
-
#update_environment_connector(params = {}) ⇒ Types::UpdateEnvironmentConnectorResponse
Updates a connector for an Amazon EVS environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-evs/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2187 2188 2189 |
# File 'lib/aws-sdk-evs/client.rb', line 2187 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2190 2191 2192 |
# File 'lib/aws-sdk-evs/client.rb', line 2190 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_eip_to_vlan(params = {}) ⇒ Types::AssociateEipToVlanResponse
Associates an Elastic IP address with a public HCX VLAN. This operation is only allowed for public HCX VLANs at this time.
87 |
# File 'sig/client.rbs', line 87
def associate_eip_to_vlan: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-evs/client.rb', line 2160 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Evs') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-evs' context[:gem_version] = '1.22.0' Seahorse::Client::Request.new(handlers, context) end |
#create_entitlement(params = {}) ⇒ Types::CreateEntitlementResponse
Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector. This is an asynchronous operation. Amazon EVS validates the specified virtual machines before starting usage tracking.
100 |
# File 'sig/client.rbs', line 100
def create_entitlement: (
|
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
SELF_DEPLOYED for vcfVersion, Amazon EVS
provisions only the VLAN subnets; no hosts are added and no VCF
installation is performed. After the environment is created, you can
add hosts with CreateEnvironmentHost and install VCF yourself. The
licenseInfo, hosts, vcfHostnames, siteId, and
connectivityInfo parameters are not supported in this mode.
When you specify any other VCF version, Amazon EVS installs and configures VCF for you. For more information, see Self-deployed mode in the Amazon EVS User Guide.
When Amazon EVS installs VCF, the default ESX version for the selected VCF version will be used. After a host is added with a specific ESX version, it can only be upgraded using vCenter Lifecycle Manager.
dedicatedHostId and placementGroupId parameters
together in the same CreateEnvironment action. This results in a
ValidationException response.
114 |
# File 'sig/client.rbs', line 114
def create_environment: (
|
#create_environment_connector(params = {}) ⇒ Types::CreateEnvironmentConnectorResponse
Creates a connector for an Amazon EVS environment. A connector allows the Amazon EVS control plane to interface with VCF appliances using a fully qualified domain name.
You can create only one connector of each type per environment. For
environments where Amazon EVS installs VCF, the SDDC_MANAGER
connector is created automatically.
198 |
# File 'sig/client.rbs', line 198
def create_environment_connector: (
|
#create_environment_host(params = {}) ⇒ Types::CreateEnvironmentHostResponse
Creates an ESX host and adds it to an Amazon EVS environment.
This action can only be used after the Amazon EVS environment is deployed.
You can use the dedicatedHostId parameter to specify an Amazon EC2
Dedicated Host for ESX host creation.
You can use the placementGroupId parameter to specify a cluster or
partition placement group to launch EC2 instances into.
CreateEnvironmentHost action, Amazon EVS automatically uses the
default ESX version for your environment's VCF version. To find the
available ESX versions for a particular VCF version, use the
GetVersions action.
You cannot use the dedicatedHostId and placementGroupId parameters
together in the same CreateEnvironmentHost action. This results in a
ValidationException response.
213 |
# File 'sig/client.rbs', line 213
def create_environment_host: (
|
#delete_entitlement(params = {}) ⇒ Types::DeleteEntitlementResponse
Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment. Deleting an entitlement stops usage tracking for the specified virtual machines.
232 |
# File 'sig/client.rbs', line 232
def delete_entitlement: (
|
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon EVS environment.
Amazon EVS environments will only be enabled for deletion once the
hosts are deleted. You can delete hosts using the
DeleteEnvironmentHost action.
Environment deletion also deletes the associated Amazon EVS VLAN subnets and Amazon Web Services Secrets Manager secrets that Amazon EVS created. Amazon Web Services resources that you create are not deleted. These resources may continue to incur costs.
246 |
# File 'sig/client.rbs', line 246
def delete_environment: (
|
#delete_environment_connector(params = {}) ⇒ Types::DeleteEnvironmentConnectorResponse
Deletes a connector from an Amazon EVS environment.
258 |
# File 'sig/client.rbs', line 258
def delete_environment_connector: (
|
#delete_environment_host(params = {}) ⇒ Types::DeleteEnvironmentHostResponse
Deletes a host from an Amazon EVS environment.
271 |
# File 'sig/client.rbs', line 271
def delete_environment_host: (
|
#disassociate_eip_from_vlan(params = {}) ⇒ Types::DisassociateEipFromVlanResponse
Disassociates an Elastic IP address from a public HCX VLAN. This operation is only allowed for public HCX VLANs at this time.
283 |
# File 'sig/client.rbs', line 283
def disassociate_eip_from_vlan: (
|
#get_depot_url(params = {}) ⇒ Types::GetDepotUrlResponse
Returns a URL and authentication token for accessing the Amazon EVS Custom Addon depot. Configure the depot URL as a download source in vSphere Lifecycle Manager (vLCM) to sync and install the Amazon EVS Custom Addon.
The depot URL remains active until you rotate the authentication token
by calling this action with rotate set to true.
297 |
# File 'sig/client.rbs', line 297
def get_depot_url: (
|
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns a description of the specified environment.
308 |
# File 'sig/client.rbs', line 308
def get_environment: (
|
#get_versions(params = {}) ⇒ Types::GetVersionsResponse
Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS. For each VCF version, the response also includes the default ESX version and provided EC2 instance types.
319 |
# File 'sig/client.rbs', line 319
def get_versions: (
|
#list_environment_connectors(params = {}) ⇒ Types::ListEnvironmentConnectorsResponse
Lists the connectors within an environment. Returns the status of each connector and its applicable checks, among other connector details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
329 |
# File 'sig/client.rbs', line 329
def list_environment_connectors: (
|
#list_environment_hosts(params = {}) ⇒ Types::ListEnvironmentHostsResponse
List the hosts within an environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
342 |
# File 'sig/client.rbs', line 342
def list_environment_hosts: (
|
#list_environment_vlans(params = {}) ⇒ Types::ListEnvironmentVlansResponse
Lists environment VLANs that are associated with the specified environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
355 |
# File 'sig/client.rbs', line 355
def list_environment_vlans: (
|
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
368 |
# File 'sig/client.rbs', line 368
def list_environments: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for an Amazon EVS resource.
380 |
# File 'sig/client.rbs', line 380
def list_tags_for_resource: (
|
#list_vm_entitlements(params = {}) ⇒ Types::ListVmEntitlementsResponse
Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment. Returns existing entitlements for virtual machines associated with the specified environment and connector.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
391 |
# File 'sig/client.rbs', line 391
def list_vm_entitlements: (
|
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to an Amazon EVS resource with the
specified resourceArn. If existing tags on a resource are not
specified in the request parameters, they aren't changed. When a
resource is deleted, the tags associated with that resource are also
deleted. Tags that you create for Amazon EVS resources don't
propagate to any other resources associated with the environment. For
example, if you tag an environment with this operation, that tag
doesn't automatically propagate to the VLAN subnets and hosts
associated with the environment.
404 |
# File 'sig/client.rbs', line 404
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from an Amazon EVS resource.
414 |
# File 'sig/client.rbs', line 414
def untag_resource: (
|
#update_environment_connector(params = {}) ⇒ Types::UpdateEnvironmentConnectorResponse
Updates a connector for an Amazon EVS environment. You can update the Amazon Web Services Secrets Manager secret ARN or the appliance FQDN to reconfigure the connector metadata.
425 |
# File 'sig/client.rbs', line 425
def update_environment_connector: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2180 2181 2182 |
# File 'lib/aws-sdk-evs/client.rb', line 2180 def waiter_names [] end |