Class: Aws::Evs::Types::Check

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

A check on the environment to identify environment health and validate VMware VCF licensing compliance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

A unique ID for the check.

Returns:

  • (String)


127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-evs/types.rb', line 127

class Check < Struct.new(
  :type,
  :id,
  :result,
  :impaired_since)
  SENSITIVE = []
  include Aws::Structure
end

#impaired_sinceTime

The time when environment health began to be impaired.

Returns:

  • (Time)


127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-evs/types.rb', line 127

class Check < Struct.new(
  :type,
  :id,
  :result,
  :impaired_since)
  SENSITIVE = []
  include Aws::Structure
end

#resultString

The check result.

Returns:

  • (String)


127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-evs/types.rb', line 127

class Check < Struct.new(
  :type,
  :id,
  :result,
  :impaired_since)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The check type. Amazon EVS performs the following checks:

  • KEY_REUSE: Verifies that the VCF license key is not used by another Amazon EVS environment.

  • KEY_COVERAGE: Verifies that the VCF license key allocates sufficient vCPU cores for all deployed hosts.

  • REACHABILITY: Verifies that the Amazon EVS control plane has a persistent connection to SDDC Manager.

  • HOST_COUNT: Verifies that the environment meets the minimum host count.

  • VCENTER_REACHABILITY: Verifies vCenter Server reachability through the vCenter connector.

  • VCENTER_VM_SYNC: Verifies that the vCenter connector can synchronize VM inventory from vCenter Server.

  • VCENTER_VM_EVENT: Verifies that the vCenter connector can receive VM lifecycle events from vCenter Server.

  • OPERATIONS_MANAGER_REACHABILITY: Verifies Operations Manager reachability through the Operations Manager connector.

  • SDDC_MANAGER_REACHABILITY: Verifies SDDC Manager reachability through the SDDC Manager connector.

  • SDDC_MANAGER_HOST_COUNT: Verifies that the host count reported by SDDC Manager meets Amazon EVS minimum requirements.

  • SDDC_MANAGER_KEY_COVERAGE: Verifies that the VCF license key configured in SDDC Manager covers all deployed hosts.

  • SDDC_MANAGER_KEY_REUSE: Verifies that the VCF license key configured in SDDC Manager is not used by another Amazon EVS environment.

  • CONNECTOR_HEALTH: Aggregate health across all connectors in the environment.

Returns:

  • (String)


127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-evs/types.rb', line 127

class Check < Struct.new(
  :type,
  :id,
  :result,
  :impaired_since)
  SENSITIVE = []
  include Aws::Structure
end