Class: Aws::Evs::Types::ConnectivityInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

The connectivity configuration for the environment. Amazon EVS requires that you specify two route server peer IDs. During environment creation, the route server endpoints peer with the NSX uplink VLAN for connectivity to the NSX overlay network.

Not supported when vcfVersion is SELF_DEPLOYED.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#private_route_server_peeringsArray<String>

The unique IDs for private route server peers.

Returns:

  • (Array<String>)


151
152
153
154
155
# File 'lib/aws-sdk-evs/types.rb', line 151

class ConnectivityInfo < Struct.new(
  :private_route_server_peerings)
  SENSITIVE = []
  include Aws::Structure
end