Class: Aws::Evs::Types::ConnectorCheck
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::ConnectorCheck
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
A check on a connector to identify connectivity health.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#impaired_since ⇒ Time
The time when connector health began to be impaired.
-
#last_check_attempt ⇒ Time
The date and time of the last check attempt.
-
#result ⇒ String
The check result.
-
#type ⇒ String
The check type.
Instance Attribute Details
#impaired_since ⇒ Time
The time when connector health began to be impaired.
217 218 219 220 221 222 223 224 |
# File 'lib/aws-sdk-evs/types.rb', line 217 class ConnectorCheck < Struct.new( :type, :result, :last_check_attempt, :impaired_since) SENSITIVE = [] include Aws::Structure end |
#last_check_attempt ⇒ Time
The date and time of the last check attempt.
217 218 219 220 221 222 223 224 |
# File 'lib/aws-sdk-evs/types.rb', line 217 class ConnectorCheck < Struct.new( :type, :result, :last_check_attempt, :impaired_since) SENSITIVE = [] include Aws::Structure end |
#result ⇒ String
The check result.
217 218 219 220 221 222 223 224 |
# File 'lib/aws-sdk-evs/types.rb', line 217 class ConnectorCheck < Struct.new( :type, :result, :last_check_attempt, :impaired_since) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The check type.
217 218 219 220 221 222 223 224 |
# File 'lib/aws-sdk-evs/types.rb', line 217 class ConnectorCheck < Struct.new( :type, :result, :last_check_attempt, :impaired_since) SENSITIVE = [] include Aws::Structure end |