Class: Aws::Evs::Types::CreateEntitlementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

<note markdown=“1”> This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.

</note>

A unique, case-sensitive identifier that you provide to ensure the

idempotency of the entitlement creation request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


261
262
263
264
265
266
267
268
269
# File 'lib/aws-sdk-evs/types.rb', line 261

class CreateEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end

#connector_idString

A unique ID for the connector associated with the entitlement.

Returns:

  • (String)


261
262
263
264
265
266
267
268
269
# File 'lib/aws-sdk-evs/types.rb', line 261

class CreateEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end

#entitlement_typeString

The type of entitlement to create.

Returns:

  • (String)


261
262
263
264
265
266
267
268
269
# File 'lib/aws-sdk-evs/types.rb', line 261

class CreateEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

A unique ID for the environment to create the entitlement in.

Returns:

  • (String)


261
262
263
264
265
266
267
268
269
# File 'lib/aws-sdk-evs/types.rb', line 261

class CreateEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vm_idsArray<String>

The list of VMware vSphere virtual machine managed object IDs to create entitlements for.

Returns:

  • (Array<String>)


261
262
263
264
265
266
267
268
269
# File 'lib/aws-sdk-evs/types.rb', line 261

class CreateEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end