Class: Aws::Evs::Types::DeleteEntitlementRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

<note markdown=“1”> This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.

</note>

A unique, case-sensitive identifier that you provide to ensure the

idempotency of the entitlement deletion request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


631
632
633
634
635
636
637
638
639
# File 'lib/aws-sdk-evs/types.rb', line 631

class DeleteEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end

#connector_idString

A unique ID for the connector associated with the entitlement.

Returns:

  • (String)


631
632
633
634
635
636
637
638
639
# File 'lib/aws-sdk-evs/types.rb', line 631

class DeleteEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end

#entitlement_typeString

The type of entitlement to delete.

Returns:

  • (String)


631
632
633
634
635
636
637
638
639
# File 'lib/aws-sdk-evs/types.rb', line 631

class DeleteEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

A unique ID for the environment that the entitlement belongs to.

Returns:

  • (String)


631
632
633
634
635
636
637
638
639
# File 'lib/aws-sdk-evs/types.rb', line 631

class DeleteEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end

#vm_idsArray<String>

The list of VMware vSphere virtual machine managed object IDs to delete entitlements for.

Returns:

  • (Array<String>)


631
632
633
634
635
636
637
638
639
# File 'lib/aws-sdk-evs/types.rb', line 631

class DeleteEntitlementRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :entitlement_type,
  :vm_ids)
  SENSITIVE = []
  include Aws::Structure
end