Class: Aws::Evs::Types::DeleteEnvironmentConnectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::DeleteEnvironmentConnectorResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector ⇒ Types::Connector
A description of the deleted connector.
-
#environment_summary ⇒ Types::EnvironmentSummary
A summary of the environment that the connector was deleted from.
Instance Attribute Details
#connector ⇒ Types::Connector
A description of the deleted connector.
697 698 699 700 701 702 |
# File 'lib/aws-sdk-evs/types.rb', line 697 class DeleteEnvironmentConnectorResponse < Struct.new( :connector, :environment_summary) SENSITIVE = [] include Aws::Structure end |
#environment_summary ⇒ Types::EnvironmentSummary
A summary of the environment that the connector was deleted from.
697 698 699 700 701 702 |
# File 'lib/aws-sdk-evs/types.rb', line 697 class DeleteEnvironmentConnectorResponse < Struct.new( :connector, :environment_summary) SENSITIVE = [] include Aws::Structure end |