Class: Aws::Evs::Types::DeleteEnvironmentHostResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::DeleteEnvironmentHostResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment_summary ⇒ Types::EnvironmentSummary
A summary of the environment that the host was deleted from.
-
#host ⇒ Types::Host
A description of the deleted host.
Instance Attribute Details
#environment_summary ⇒ Types::EnvironmentSummary
A summary of the environment that the host was deleted from.
755 756 757 758 759 760 |
# File 'lib/aws-sdk-evs/types.rb', line 755 class DeleteEnvironmentHostResponse < Struct.new( :environment_summary, :host) SENSITIVE = [] include Aws::Structure end |
#host ⇒ Types::Host
A description of the deleted host.
755 756 757 758 759 760 |
# File 'lib/aws-sdk-evs/types.rb', line 755 class DeleteEnvironmentHostResponse < Struct.new( :environment_summary, :host) SENSITIVE = [] include Aws::Structure end |