Class: Aws::Evs::Types::GetDepotUrlRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::GetDepotUrlRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment_id ⇒ String
The unique ID of the Amazon EVS environment to get the depot URL for.
-
#rotate ⇒ Boolean
Revokes the current authentication token and returns a new depot URL with a new token.
Instance Attribute Details
#environment_id ⇒ String
The unique ID of the Amazon EVS environment to get the depot URL for.
1122 1123 1124 1125 1126 1127 |
# File 'lib/aws-sdk-evs/types.rb', line 1122 class GetDepotUrlRequest < Struct.new( :environment_id, :rotate) SENSITIVE = [] include Aws::Structure end |
#rotate ⇒ Boolean
Revokes the current authentication token and returns a new depot URL with a new token. Previously issued depot URLs will stop working within 5 minutes of rotation.
1122 1123 1124 1125 1126 1127 |
# File 'lib/aws-sdk-evs/types.rb', line 1122 class GetDepotUrlRequest < Struct.new( :environment_id, :rotate) SENSITIVE = [] include Aws::Structure end |