Class: Aws::Evs::Types::Host

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

An ESX host that runs on an Amazon EC2 bare metal instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time that the host was created.

Returns:

  • (Time)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#dedicated_host_idString

The unique ID of the Amazon EC2 Dedicated Host.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_instance_idString

The unique ID of the EC2 instance that represents the host.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#host_nameString

The DNS hostname of the host. DNS hostnames for hosts must be unique across Amazon EVS environments and within VCF.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#host_stateString

The state of the host.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The EC2 instance type of the host.

EC2 instances created through Amazon EVS do not support associating an IAM instance profile.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#ip_addressString

The IP address of the host.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#key_nameString

The name of the SSH key that is used to access the host.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The date and time that the host was modified.

Returns:

  • (Time)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#network_interfacesArray<Types::NetworkInterface>

The elastic network interfaces that are attached to the host.

Returns:



1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#placement_group_idString

The unique ID of the placement group where the host is placed.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end

#state_detailsString

A detailed description of the hostState of a host.

Returns:

  • (String)


1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
# File 'lib/aws-sdk-evs/types.rb', line 1316

class Host < Struct.new(
  :host_name,
  :ip_address,
  :key_name,
  :instance_type,
  :placement_group_id,
  :dedicated_host_id,
  :created_at,
  :modified_at,
  :host_state,
  :state_details,
  :ec2_instance_id,
  :network_interfaces)
  SENSITIVE = []
  include Aws::Structure
end