Class: Aws::Evs::Types::HostInfoForCreate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::HostInfoForCreate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
An object that represents a host.
<note markdown=“1”> You cannot use ‘dedicatedHostId` and `placementGroupId` together in the same `HostInfoForCreate`object. This results in a `ValidationException` response.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dedicated_host_id ⇒ String
The unique ID of the Amazon EC2 Dedicated Host.
-
#host_name ⇒ String
The DNS hostname of the host.
-
#instance_type ⇒ String
The EC2 instance type that represents the host.
-
#key_name ⇒ String
The name of the SSH key that is used to access the host.
-
#placement_group_id ⇒ String
The unique ID of the placement group where the host is placed.
Instance Attribute Details
#dedicated_host_id ⇒ String
The unique ID of the Amazon EC2 Dedicated Host.
1260 1261 1262 1263 1264 1265 1266 1267 1268 |
# File 'lib/aws-sdk-evs/types.rb', line 1260 class HostInfoForCreate < Struct.new( :host_name, :key_name, :instance_type, :placement_group_id, :dedicated_host_id) SENSITIVE = [] include Aws::Structure end |
#host_name ⇒ String
The DNS hostname of the host. DNS hostnames for hosts must be unique across Amazon EVS environments and within VCF.
1260 1261 1262 1263 1264 1265 1266 1267 1268 |
# File 'lib/aws-sdk-evs/types.rb', line 1260 class HostInfoForCreate < Struct.new( :host_name, :key_name, :instance_type, :placement_group_id, :dedicated_host_id) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The EC2 instance type that represents the host.
<note markdown=“1”> Currently, Amazon EVS supports only the ‘i4i.metal` instance type.
</note>
1260 1261 1262 1263 1264 1265 1266 1267 1268 |
# File 'lib/aws-sdk-evs/types.rb', line 1260 class HostInfoForCreate < Struct.new( :host_name, :key_name, :instance_type, :placement_group_id, :dedicated_host_id) SENSITIVE = [] include Aws::Structure end |
#key_name ⇒ String
The name of the SSH key that is used to access the host.
1260 1261 1262 1263 1264 1265 1266 1267 1268 |
# File 'lib/aws-sdk-evs/types.rb', line 1260 class HostInfoForCreate < Struct.new( :host_name, :key_name, :instance_type, :placement_group_id, :dedicated_host_id) SENSITIVE = [] include Aws::Structure end |
#placement_group_id ⇒ String
The unique ID of the placement group where the host is placed.
1260 1261 1262 1263 1264 1265 1266 1267 1268 |
# File 'lib/aws-sdk-evs/types.rb', line 1260 class HostInfoForCreate < Struct.new( :host_name, :key_name, :instance_type, :placement_group_id, :dedicated_host_id) SENSITIVE = [] include Aws::Structure end |