Class: Aws::Evs::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
A service resource associated with the request could not be found. The resource might not be specified correctly, or it may have a ‘state` of `DELETED`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Describes the error encountered.
-
#resource_id ⇒ String
The ID of the resource that could not be found.
-
#resource_type ⇒ String
The type of the resource that is associated with the error.
Instance Attribute Details
#message ⇒ String
Describes the error encountered.
1767 1768 1769 1770 1771 1772 1773 |
# File 'lib/aws-sdk-evs/types.rb', line 1767 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource that could not be found.
1767 1768 1769 1770 1771 1772 1773 |
# File 'lib/aws-sdk-evs/types.rb', line 1767 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource that is associated with the error.
1767 1768 1769 1770 1771 1772 1773 |
# File 'lib/aws-sdk-evs/types.rb', line 1767 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |