Class: Aws::Evs::Types::Secret

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

A managed secret that contains the credentials for installing vCenter Server, NSX, and SDDC Manager. During environment creation, the Amazon EVS control plane uses Amazon Web Services Secrets Manager to create, encrypt, validate, and store secrets. If you choose to delete your environment, Amazon EVS also deletes the secrets that are associated with your environment. Amazon EVS does not provide managed rotation of secrets. We recommend that you rotate secrets regularly to ensure that secrets are not long-lived.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#secret_arnString

The Amazon Resource Name (ARN) of the secret.

Returns:

  • (String)


1790
1791
1792
1793
1794
# File 'lib/aws-sdk-evs/types.rb', line 1790

class Secret < Struct.new(
  :secret_arn)
  SENSITIVE = []
  include Aws::Structure
end