Class: Aws::Evs::Types::ThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

The operation could not be performed because the service is throttling requests. This exception is thrown when the service endpoint receives too many concurrent requests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Describes the error encountered.

Returns:

  • (String)


1908
1909
1910
1911
1912
1913
# File 'lib/aws-sdk-evs/types.rb', line 1908

class ThrottlingException < Struct.new(
  :message,
  :retry_after_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#retry_after_secondsInteger

The seconds to wait to retry.

Returns:

  • (Integer)


1908
1909
1910
1911
1912
1913
# File 'lib/aws-sdk-evs/types.rb', line 1908

class ThrottlingException < Struct.new(
  :message,
  :retry_after_seconds)
  SENSITIVE = []
  include Aws::Structure
end