Class: Aws::Evs::Types::UpdateEnvironmentConnectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#appliance_fqdnString

The new fully qualified domain name (FQDN) of the VCF appliance that the connector connects to.

Returns:

  • (String)


2094
2095
2096
2097
2098
2099
2100
2101
2102
# File 'lib/aws-sdk-evs/types.rb', line 2094

class UpdateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.

A unique, case-sensitive identifier that you provide to ensure the idempotency of the connector update request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2094
2095
2096
2097
2098
2099
2100
2101
2102
# File 'lib/aws-sdk-evs/types.rb', line 2094

class UpdateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#connector_idString

A unique ID for the connector to update.

Returns:

  • (String)


2094
2095
2096
2097
2098
2099
2100
2101
2102
# File 'lib/aws-sdk-evs/types.rb', line 2094

class UpdateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

A unique ID for the environment that the connector belongs to.

Returns:

  • (String)


2094
2095
2096
2097
2098
2099
2100
2101
2102
# File 'lib/aws-sdk-evs/types.rb', line 2094

class UpdateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#secret_identifierString

The new ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.

Returns:

  • (String)


2094
2095
2096
2097
2098
2099
2100
2101
2102
# File 'lib/aws-sdk-evs/types.rb', line 2094

class UpdateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :connector_id,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end