Class: Aws::Evs::Types::ValidationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

The input fails to satisfy the specified constraints. You will see this exception if invalid inputs are provided for any of the Amazon EVS environment operations, or if a list operation is performed on an environment resource that is still initializing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_listArray<Types::ValidationExceptionField>

A list of fields that didn’t validate.



2076
2077
2078
2079
2080
2081
2082
# File 'lib/aws-sdk-evs/types.rb', line 2076

class ValidationException < Struct.new(
  :message,
  :reason,
  :field_list)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Describes the error encountered.

Returns:

  • (String)


2076
2077
2078
2079
2080
2081
2082
# File 'lib/aws-sdk-evs/types.rb', line 2076

class ValidationException < Struct.new(
  :message,
  :reason,
  :field_list)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason for the exception.

Returns:

  • (String)


2076
2077
2078
2079
2080
2081
2082
# File 'lib/aws-sdk-evs/types.rb', line 2076

class ValidationException < Struct.new(
  :message,
  :reason,
  :field_list)
  SENSITIVE = []
  include Aws::Structure
end