Class: Aws::Evs::Types::Vlan
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::Vlan
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
The VLANs that Amazon EVS creates during environment creation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The availability zone of the VLAN.
-
#cidr ⇒ String
The CIDR block of the VLAN.
-
#created_at ⇒ Time
The date and time that the VLAN was created.
-
#eip_associations ⇒ Array<Types::EipAssociation>
An array of Elastic IP address associations.
-
#function_name ⇒ String
The VMware VCF traffic type that is carried over the VLAN.
-
#is_public ⇒ Boolean
Determines if the VLAN that Amazon EVS provisions is public or private.
-
#modified_at ⇒ Time
The date and time that the VLAN was modified.
-
#network_acl_id ⇒ String
A unique ID for a network access control list.
-
#state_details ⇒ String
The state details of the VLAN.
-
#subnet_id ⇒ String
The unique ID of the VLAN subnet.
-
#vlan_id ⇒ Integer
The unique ID of the VLAN.
-
#vlan_state ⇒ String
The state of the VLAN.
Instance Attribute Details
#availability_zone ⇒ String
The availability zone of the VLAN.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#cidr ⇒ String
The CIDR block of the VLAN. Amazon EVS VLAN subnets have a minimum CIDR block size of /28 and a maximum size of /24.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the VLAN was created.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#eip_associations ⇒ Array<Types::EipAssociation>
An array of Elastic IP address associations.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The VMware VCF traffic type that is carried over the VLAN. For example, a VLAN with a ‘functionName` of `hcx` is being used to carry VMware HCX traffic.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#is_public ⇒ Boolean
Determines if the VLAN that Amazon EVS provisions is public or private.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time that the VLAN was modified.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#network_acl_id ⇒ String
A unique ID for a network access control list.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
The state details of the VLAN.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The unique ID of the VLAN subnet.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#vlan_id ⇒ Integer
The unique ID of the VLAN.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |
#vlan_state ⇒ String
The state of the VLAN.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/aws-sdk-evs/types.rb', line 2219 class Vlan < Struct.new( :vlan_id, :cidr, :availability_zone, :function_name, :subnet_id, :created_at, :modified_at, :vlan_state, :state_details, :eip_associations, :is_public, :network_acl_id) SENSITIVE = [] include Aws::Structure end |