Class: Aws::Evs::Types::VmEntitlement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

An object that represents a Windows Server License entitlement for a virtual machine in an Amazon EVS environment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_idString

The unique ID of the connector associated with the entitlement.

Returns:

  • (String)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

The unique ID of the environment.

Returns:

  • (String)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#error_detailTypes::ErrorDetail

The error details associated with the entitlement, if applicable.

Returns:



2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#last_synced_atTime

The date and time that the entitlement was last synced.

Returns:

  • (Time)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The date and time that the entitlement started.

Returns:

  • (Time)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the entitlement.

Returns:

  • (String)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#stopped_atTime

The date and time that the entitlement stopped.

Returns:

  • (Time)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of entitlement.

Returns:

  • (String)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#vm_idString

The unique ID of the virtual machine.

Returns:

  • (String)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end

#vm_nameString

The name of the virtual machine.

Returns:

  • (String)


2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/aws-sdk-evs/types.rb', line 2281

class VmEntitlement < Struct.new(
  :vm_id,
  :environment_id,
  :connector_id,
  :vm_name,
  :type,
  :status,
  :last_synced_at,
  :started_at,
  :stopped_at,
  :error_detail)
  SENSITIVE = []
  include Aws::Structure
end