Class: Aws::Evs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Evs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-evs/client.rb
Overview
An API client for Evs. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Evs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_eip_to_vlan(params = {}) ⇒ Types::AssociateEipToVlanResponse
Associates an Elastic IP address with a public HCX VLAN.
-
#create_entitlement(params = {}) ⇒ Types::CreateEntitlementResponse
Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
-
#create_environment_connector(params = {}) ⇒ Types::CreateEnvironmentConnectorResponse
Creates a connector for an Amazon EVS environment.
-
#create_environment_host(params = {}) ⇒ Types::CreateEnvironmentHostResponse
Creates an ESX host and adds it to an Amazon EVS environment.
-
#delete_entitlement(params = {}) ⇒ Types::DeleteEntitlementResponse
Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment.
-
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon EVS environment.
-
#delete_environment_connector(params = {}) ⇒ Types::DeleteEnvironmentConnectorResponse
Deletes a connector from an Amazon EVS environment.
-
#delete_environment_host(params = {}) ⇒ Types::DeleteEnvironmentHostResponse
Deletes a host from an Amazon EVS environment.
-
#disassociate_eip_from_vlan(params = {}) ⇒ Types::DisassociateEipFromVlanResponse
Disassociates an Elastic IP address from a public HCX VLAN.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns a description of the specified environment.
-
#get_versions(params = {}) ⇒ Types::GetVersionsResponse
Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS.
-
#list_environment_connectors(params = {}) ⇒ Types::ListEnvironmentConnectorsResponse
Lists the connectors within an environment.
-
#list_environment_hosts(params = {}) ⇒ Types::ListEnvironmentHostsResponse
List the hosts within an environment.
-
#list_environment_vlans(params = {}) ⇒ Types::ListEnvironmentVlansResponse
Lists environment VLANs that are associated with the specified environment.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for an Amazon EVS resource.
-
#list_vm_entitlements(params = {}) ⇒ Types::ListVmEntitlementsResponse
Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to an Amazon EVS resource with the specified ‘resourceArn`.
-
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from an Amazon EVS resource.
-
#update_environment_connector(params = {}) ⇒ Types::UpdateEnvironmentConnectorResponse
Updates a connector for an Amazon EVS environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-evs/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2095 2096 2097 |
# File 'lib/aws-sdk-evs/client.rb', line 2095 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2098 2099 2100 |
# File 'lib/aws-sdk-evs/client.rb', line 2098 def errors_module Errors end |
Instance Method Details
#associate_eip_to_vlan(params = {}) ⇒ Types::AssociateEipToVlanResponse
Associates an Elastic IP address with a public HCX VLAN. This operation is only allowed for public HCX VLANs at this time.
550 551 552 553 |
# File 'lib/aws-sdk-evs/client.rb', line 550 def associate_eip_to_vlan(params = {}, = {}) req = build_request(:associate_eip_to_vlan, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-evs/client.rb', line 2068 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Evs') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-evs' context[:gem_version] = '1.16.0' Seahorse::Client::Request.new(handlers, context) end |
#create_entitlement(params = {}) ⇒ Types::CreateEntitlementResponse
Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector. This is an asynchronous operation. Amazon EVS validates the specified virtual machines before starting usage tracking.
621 622 623 624 |
# File 'lib/aws-sdk-evs/client.rb', line 621 def create_entitlement(params = {}, = {}) req = build_request(:create_entitlement, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
During environment creation, Amazon EVS performs validations on DNS settings, provisions VLAN subnets and hosts, and deploys the supplied version of VCF.
It can take several hours to create an environment. After the deployment completes, you can configure VCF in the vSphere user interface according to your needs.
When creating a new environment, the default ESX version for the selected VCF version will be used, you cannot choose a specific ESX version in ‘CreateEnvironment` action. When a host has been added with a specific ESX version, it can only be upgraded using vCenter Lifecycle Manager.
<note markdown=“1”> You cannot use the ‘dedicatedHostId` and `placementGroupId` parameters together in the same `CreateEnvironment` action. This results in a `ValidationException` response.
</note>
928 929 930 931 |
# File 'lib/aws-sdk-evs/client.rb', line 928 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_environment_connector(params = {}) ⇒ Types::CreateEnvironmentConnectorResponse
Creates a connector for an Amazon EVS environment. A connector establishes a connection to a VCF appliance, such as vCenter, using a fully qualified domain name and an Amazon Web Services Secrets Manager secret that stores the appliance credentials.
1006 1007 1008 1009 |
# File 'lib/aws-sdk-evs/client.rb', line 1006 def create_environment_connector(params = {}, = {}) req = build_request(:create_environment_connector, params) req.send_request() end |
#create_environment_host(params = {}) ⇒ Types::CreateEnvironmentHostResponse
Creates an ESX host and adds it to an Amazon EVS environment. Amazon EVS supports 4-16 hosts per environment.
This action can only be used after the Amazon EVS environment is deployed.
You can use the ‘dedicatedHostId` parameter to specify an Amazon EC2 Dedicated Host for ESX host creation.
You can use the ‘placementGroupId` parameter to specify a cluster or partition placement group to launch EC2 instances into.
<note markdown=“1”> If you don’t specify an ESX version when adding hosts using ‘CreateEnvironmentHost` action, Amazon EVS automatically uses the default ESX version associated with your environment’s VCF version. To find the default ESX version for a particular VCF version, use the ‘GetVersions` action.
</note>
<note markdown=“1”> You cannot use the ‘dedicatedHostId` and `placementGroupId` parameters together in the same `CreateEnvironmentHost` action. This results in a `ValidationException` response.
</note>
1109 1110 1111 1112 |
# File 'lib/aws-sdk-evs/client.rb', line 1109 def create_environment_host(params = {}, = {}) req = build_request(:create_environment_host, params) req.send_request() end |
#delete_entitlement(params = {}) ⇒ Types::DeleteEntitlementResponse
Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment. Deleting an entitlement stops usage tracking for the specified virtual machines.
1179 1180 1181 1182 |
# File 'lib/aws-sdk-evs/client.rb', line 1179 def delete_entitlement(params = {}, = {}) req = build_request(:delete_entitlement, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon EVS environment.
Amazon EVS environments will only be enabled for deletion once the hosts are deleted. You can delete hosts using the ‘DeleteEnvironmentHost` action.
Environment deletion also deletes the associated Amazon EVS VLAN subnets and Amazon Web Services Secrets Manager secrets that Amazon EVS created. Amazon Web Services resources that you create are not deleted. These resources may continue to incur costs.
1267 1268 1269 1270 |
# File 'lib/aws-sdk-evs/client.rb', line 1267 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#delete_environment_connector(params = {}) ⇒ Types::DeleteEnvironmentConnectorResponse
Deletes a connector from an Amazon EVS environment.
<note markdown=“1”> Before deleting a connector, you must remove all entitlements that are associated with the same vCenter.
</note>
1343 1344 1345 1346 |
# File 'lib/aws-sdk-evs/client.rb', line 1343 def delete_environment_connector(params = {}, = {}) req = build_request(:delete_environment_connector, params) req.send_request() end |
#delete_environment_host(params = {}) ⇒ Types::DeleteEnvironmentHostResponse
Deletes a host from an Amazon EVS environment.
<note markdown=“1”> Before deleting a host, you must unassign and decommission the host from within the SDDC Manager user interface. Not doing so could impact the availability of your virtual machines or result in data loss.
</note>
1418 1419 1420 1421 |
# File 'lib/aws-sdk-evs/client.rb', line 1418 def delete_environment_host(params = {}, = {}) req = build_request(:delete_environment_host, params) req.send_request() end |
#disassociate_eip_from_vlan(params = {}) ⇒ Types::DisassociateEipFromVlanResponse
Disassociates an Elastic IP address from a public HCX VLAN. This operation is only allowed for public HCX VLANs at this time.
1487 1488 1489 1490 |
# File 'lib/aws-sdk-evs/client.rb', line 1487 def disassociate_eip_from_vlan(params = {}, = {}) req = build_request(:disassociate_eip_from_vlan, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns a description of the specified environment.
1550 1551 1552 1553 |
# File 'lib/aws-sdk-evs/client.rb', line 1550 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#get_versions(params = {}) ⇒ Types::GetVersionsResponse
Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS. For each VCF version, the response also includes the default ESX version and provided EC2 instance types.
1581 1582 1583 1584 |
# File 'lib/aws-sdk-evs/client.rb', line 1581 def get_versions(params = {}, = {}) req = build_request(:get_versions, params) req.send_request() end |
#list_environment_connectors(params = {}) ⇒ Types::ListEnvironmentConnectorsResponse
Lists the connectors within an environment. Returns the status of each connector and its applicable checks, among other connector details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1643 1644 1645 1646 |
# File 'lib/aws-sdk-evs/client.rb', line 1643 def list_environment_connectors(params = {}, = {}) req = build_request(:list_environment_connectors, params) req.send_request() end |
#list_environment_hosts(params = {}) ⇒ Types::ListEnvironmentHostsResponse
List the hosts within an environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1702 1703 1704 1705 |
# File 'lib/aws-sdk-evs/client.rb', line 1702 def list_environment_hosts(params = {}, = {}) req = build_request(:list_environment_hosts, params) req.send_request() end |
#list_environment_vlans(params = {}) ⇒ Types::ListEnvironmentVlansResponse
Lists environment VLANs that are associated with the specified environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1764 1765 1766 1767 |
# File 'lib/aws-sdk-evs/client.rb', line 1764 def list_environment_vlans(params = {}, = {}) req = build_request(:list_environment_vlans, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1820 1821 1822 1823 |
# File 'lib/aws-sdk-evs/client.rb', line 1820 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for an Amazon EVS resource.
1850 1851 1852 1853 |
# File 'lib/aws-sdk-evs/client.rb', line 1850 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_vm_entitlements(params = {}) ⇒ Types::ListVmEntitlementsResponse
Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment. Returns existing entitlements for virtual machines associated with the specified environment and connector.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1917 1918 1919 1920 |
# File 'lib/aws-sdk-evs/client.rb', line 1917 def list_vm_entitlements(params = {}, = {}) req = build_request(:list_vm_entitlements, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to an Amazon EVS resource with the specified ‘resourceArn`. If existing tags on a resource are not specified in the request parameters, they aren’t changed. When a resource is deleted, the tags associated with that resource are also deleted. Tags that you create for Amazon EVS resources don’t propagate to any other resources associated with the environment. For example, if you tag an environment with this operation, that tag doesn’t automatically propagate to the VLAN subnets and hosts associated with the environment.
1955 1956 1957 1958 |
# File 'lib/aws-sdk-evs/client.rb', line 1955 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from an Amazon EVS resource.
1981 1982 1983 1984 |
# File 'lib/aws-sdk-evs/client.rb', line 1981 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_environment_connector(params = {}) ⇒ Types::UpdateEnvironmentConnectorResponse
Updates a connector for an Amazon EVS environment. You can update the Amazon Web Services Secrets Manager secret ARN or the appliance FQDN to reconfigure the connector metadata.
<note markdown=“1”> You cannot update both the secret and the FQDN in the same request.
</note>
2059 2060 2061 2062 |
# File 'lib/aws-sdk-evs/client.rb', line 2059 def update_environment_connector(params = {}, = {}) req = build_request(:update_environment_connector, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2088 2089 2090 |
# File 'lib/aws-sdk-evs/client.rb', line 2088 def waiter_names [] end |