Class: Aws::Evs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Evs::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-evs/client.rb
Overview
An API client for Evs. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Evs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_eip_to_vlan(params = {}) ⇒ Types::AssociateEipToVlanResponse
Associates an Elastic IP address with a public HCX VLAN.
-
#create_entitlement(params = {}) ⇒ Types::CreateEntitlementResponse
Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
-
#create_environment_connector(params = {}) ⇒ Types::CreateEnvironmentConnectorResponse
Creates a connector for an Amazon EVS environment.
-
#create_environment_host(params = {}) ⇒ Types::CreateEnvironmentHostResponse
Creates an ESX host and adds it to an Amazon EVS environment.
-
#delete_entitlement(params = {}) ⇒ Types::DeleteEntitlementResponse
Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment.
-
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon EVS environment.
-
#delete_environment_connector(params = {}) ⇒ Types::DeleteEnvironmentConnectorResponse
Deletes a connector from an Amazon EVS environment.
-
#delete_environment_host(params = {}) ⇒ Types::DeleteEnvironmentHostResponse
Deletes a host from an Amazon EVS environment.
-
#disassociate_eip_from_vlan(params = {}) ⇒ Types::DisassociateEipFromVlanResponse
Disassociates an Elastic IP address from a public HCX VLAN.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns a description of the specified environment.
-
#get_versions(params = {}) ⇒ Types::GetVersionsResponse
Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS.
-
#list_environment_connectors(params = {}) ⇒ Types::ListEnvironmentConnectorsResponse
Lists the connectors within an environment.
-
#list_environment_hosts(params = {}) ⇒ Types::ListEnvironmentHostsResponse
List the hosts within an environment.
-
#list_environment_vlans(params = {}) ⇒ Types::ListEnvironmentVlansResponse
Lists environment VLANs that are associated with the specified environment.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for an Amazon EVS resource.
-
#list_vm_entitlements(params = {}) ⇒ Types::ListVmEntitlementsResponse
Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to an Amazon EVS resource with the specified ‘resourceArn`.
-
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from an Amazon EVS resource.
-
#update_environment_connector(params = {}) ⇒ Types::UpdateEnvironmentConnectorResponse
Updates a connector for an Amazon EVS environment.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-evs/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2088 2089 2090 |
# File 'lib/aws-sdk-evs/client.rb', line 2088 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2091 2092 2093 |
# File 'lib/aws-sdk-evs/client.rb', line 2091 def errors_module Errors end |
Instance Method Details
#associate_eip_to_vlan(params = {}) ⇒ Types::AssociateEipToVlanResponse
Associates an Elastic IP address with a public HCX VLAN. This operation is only allowed for public HCX VLANs at this time.
550 551 552 553 |
# File 'lib/aws-sdk-evs/client.rb', line 550 def associate_eip_to_vlan(params = {}, = {}) req = build_request(:associate_eip_to_vlan, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 |
# File 'lib/aws-sdk-evs/client.rb', line 2061 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Evs') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-evs' context[:gem_version] = '1.15.0' Seahorse::Client::Request.new(handlers, context) end |
#create_entitlement(params = {}) ⇒ Types::CreateEntitlementResponse
Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector. This is an asynchronous operation. Amazon EVS validates the specified virtual machines before starting usage tracking.
621 622 623 624 |
# File 'lib/aws-sdk-evs/client.rb', line 621 def create_entitlement(params = {}, = {}) req = build_request(:create_entitlement, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
During environment creation, Amazon EVS performs validations on DNS settings, provisions VLAN subnets and hosts, and deploys the supplied version of VCF.
It can take several hours to create an environment. After the deployment completes, you can configure VCF in the vSphere user interface according to your needs.
When creating a new environment, the default ESX version for the selected VCF version will be used, you cannot choose a specific ESX version in ‘CreateEnvironment` action. When a host has been added with a specific ESX version, it can only be upgraded using vCenter Lifecycle Manager.
<note markdown=“1”> You cannot use the ‘dedicatedHostId` and `placementGroupId` parameters together in the same `CreateEnvironment` action. This results in a `ValidationException` response.
</note>
921 922 923 924 |
# File 'lib/aws-sdk-evs/client.rb', line 921 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_environment_connector(params = {}) ⇒ Types::CreateEnvironmentConnectorResponse
Creates a connector for an Amazon EVS environment. A connector establishes a connection to a VCF appliance, such as vCenter, using a fully qualified domain name and an Amazon Web Services Secrets Manager secret that stores the appliance credentials.
999 1000 1001 1002 |
# File 'lib/aws-sdk-evs/client.rb', line 999 def create_environment_connector(params = {}, = {}) req = build_request(:create_environment_connector, params) req.send_request() end |
#create_environment_host(params = {}) ⇒ Types::CreateEnvironmentHostResponse
Creates an ESX host and adds it to an Amazon EVS environment. Amazon EVS supports 4-16 hosts per environment.
This action can only be used after the Amazon EVS environment is deployed.
You can use the ‘dedicatedHostId` parameter to specify an Amazon EC2 Dedicated Host for ESX host creation.
You can use the ‘placementGroupId` parameter to specify a cluster or partition placement group to launch EC2 instances into.
<note markdown=“1”> If you don’t specify an ESX version when adding hosts using ‘CreateEnvironmentHost` action, Amazon EVS automatically uses the default ESX version associated with your environment’s VCF version. To find the default ESX version for a particular VCF version, use the ‘GetVersions` action.
</note>
<note markdown=“1”> You cannot use the ‘dedicatedHostId` and `placementGroupId` parameters together in the same `CreateEnvironmentHost` action. This results in a `ValidationException` response.
</note>
1102 1103 1104 1105 |
# File 'lib/aws-sdk-evs/client.rb', line 1102 def create_environment_host(params = {}, = {}) req = build_request(:create_environment_host, params) req.send_request() end |
#delete_entitlement(params = {}) ⇒ Types::DeleteEntitlementResponse
Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment. Deleting an entitlement stops usage tracking for the specified virtual machines.
1172 1173 1174 1175 |
# File 'lib/aws-sdk-evs/client.rb', line 1172 def delete_entitlement(params = {}, = {}) req = build_request(:delete_entitlement, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon EVS environment.
Amazon EVS environments will only be enabled for deletion once the hosts are deleted. You can delete hosts using the ‘DeleteEnvironmentHost` action.
Environment deletion also deletes the associated Amazon EVS VLAN subnets and Amazon Web Services Secrets Manager secrets that Amazon EVS created. Amazon Web Services resources that you create are not deleted. These resources may continue to incur costs.
1260 1261 1262 1263 |
# File 'lib/aws-sdk-evs/client.rb', line 1260 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#delete_environment_connector(params = {}) ⇒ Types::DeleteEnvironmentConnectorResponse
Deletes a connector from an Amazon EVS environment.
<note markdown=“1”> Before deleting a connector, you must remove all entitlements that are associated with the same vCenter.
</note>
1336 1337 1338 1339 |
# File 'lib/aws-sdk-evs/client.rb', line 1336 def delete_environment_connector(params = {}, = {}) req = build_request(:delete_environment_connector, params) req.send_request() end |
#delete_environment_host(params = {}) ⇒ Types::DeleteEnvironmentHostResponse
Deletes a host from an Amazon EVS environment.
<note markdown=“1”> Before deleting a host, you must unassign and decommission the host from within the SDDC Manager user interface. Not doing so could impact the availability of your virtual machines or result in data loss.
</note>
1411 1412 1413 1414 |
# File 'lib/aws-sdk-evs/client.rb', line 1411 def delete_environment_host(params = {}, = {}) req = build_request(:delete_environment_host, params) req.send_request() end |
#disassociate_eip_from_vlan(params = {}) ⇒ Types::DisassociateEipFromVlanResponse
Disassociates an Elastic IP address from a public HCX VLAN. This operation is only allowed for public HCX VLANs at this time.
1480 1481 1482 1483 |
# File 'lib/aws-sdk-evs/client.rb', line 1480 def disassociate_eip_from_vlan(params = {}, = {}) req = build_request(:disassociate_eip_from_vlan, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns a description of the specified environment.
1543 1544 1545 1546 |
# File 'lib/aws-sdk-evs/client.rb', line 1543 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#get_versions(params = {}) ⇒ Types::GetVersionsResponse
Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS. For each VCF version, the response also includes the default ESX version and provided EC2 instance types.
1574 1575 1576 1577 |
# File 'lib/aws-sdk-evs/client.rb', line 1574 def get_versions(params = {}, = {}) req = build_request(:get_versions, params) req.send_request() end |
#list_environment_connectors(params = {}) ⇒ Types::ListEnvironmentConnectorsResponse
Lists the connectors within an environment. Returns the status of each connector and its applicable checks, among other connector details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1636 1637 1638 1639 |
# File 'lib/aws-sdk-evs/client.rb', line 1636 def list_environment_connectors(params = {}, = {}) req = build_request(:list_environment_connectors, params) req.send_request() end |
#list_environment_hosts(params = {}) ⇒ Types::ListEnvironmentHostsResponse
List the hosts within an environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1695 1696 1697 1698 |
# File 'lib/aws-sdk-evs/client.rb', line 1695 def list_environment_hosts(params = {}, = {}) req = build_request(:list_environment_hosts, params) req.send_request() end |
#list_environment_vlans(params = {}) ⇒ Types::ListEnvironmentVlansResponse
Lists environment VLANs that are associated with the specified environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1757 1758 1759 1760 |
# File 'lib/aws-sdk-evs/client.rb', line 1757 def list_environment_vlans(params = {}, = {}) req = build_request(:list_environment_vlans, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1813 1814 1815 1816 |
# File 'lib/aws-sdk-evs/client.rb', line 1813 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for an Amazon EVS resource.
1843 1844 1845 1846 |
# File 'lib/aws-sdk-evs/client.rb', line 1843 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_vm_entitlements(params = {}) ⇒ Types::ListVmEntitlementsResponse
Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment. Returns existing entitlements for virtual machines associated with the specified environment and connector.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1910 1911 1912 1913 |
# File 'lib/aws-sdk-evs/client.rb', line 1910 def list_vm_entitlements(params = {}, = {}) req = build_request(:list_vm_entitlements, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to an Amazon EVS resource with the specified ‘resourceArn`. If existing tags on a resource are not specified in the request parameters, they aren’t changed. When a resource is deleted, the tags associated with that resource are also deleted. Tags that you create for Amazon EVS resources don’t propagate to any other resources associated with the environment. For example, if you tag an environment with this operation, that tag doesn’t automatically propagate to the VLAN subnets and hosts associated with the environment.
1948 1949 1950 1951 |
# File 'lib/aws-sdk-evs/client.rb', line 1948 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from an Amazon EVS resource.
1974 1975 1976 1977 |
# File 'lib/aws-sdk-evs/client.rb', line 1974 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_environment_connector(params = {}) ⇒ Types::UpdateEnvironmentConnectorResponse
Updates a connector for an Amazon EVS environment. You can update the Amazon Web Services Secrets Manager secret ARN or the appliance FQDN to reconfigure the connector metadata.
<note markdown=“1”> You cannot update both the secret and the FQDN in the same request.
</note>
2052 2053 2054 2055 |
# File 'lib/aws-sdk-evs/client.rb', line 2052 def update_environment_connector(params = {}, = {}) req = build_request(:update_environment_connector, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2081 2082 2083 |
# File 'lib/aws-sdk-evs/client.rb', line 2081 def waiter_names [] end |