Class: Aws::Evs::Types::Connector

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

An object that represents a connector for an Amazon EVS environment. A connector establishes a vCenter connection using the credentials stored in Amazon Web Services Secrets Manager.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#appliance_fqdnString

The fully qualified domain name (FQDN) of the VCF appliance that the connector connects to.

Returns:

  • (String)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#checksArray<Types::ConnectorCheck>

A list of checks that are run on the connector.

Returns:



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#connector_idString

The unique ID of the connector.

Returns:

  • (String)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the connector was created.

Returns:

  • (Time)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

The unique ID of the environment that the connector belongs to.

Returns:

  • (String)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The date and time that the connector was modified.

Returns:

  • (Time)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.

Returns:

  • (String)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the connector.

Returns:

  • (String)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#state_detailsString

A detailed description of the connector state.

Returns:

  • (String)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the connector.

Returns:

  • (String)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the connector.

Returns:

  • (String)


181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-evs/types.rb', line 181

class Connector < Struct.new(
  :environment_id,
  :connector_id,
  :type,
  :appliance_fqdn,
  :secret_arn,
  :state,
  :state_details,
  :status,
  :checks,
  :created_at,
  :modified_at)
  SENSITIVE = []
  include Aws::Structure
end