Class: Aws::Evs::Types::Connector
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::Connector
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
An object that represents a connector for an Amazon EVS environment. A connector establishes a vCenter connection using the credentials stored in Amazon Web Services Secrets Manager.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#appliance_fqdn ⇒ String
The fully qualified domain name (FQDN) of the VCF appliance that the connector connects to.
-
#checks ⇒ Array<Types::ConnectorCheck>
A list of checks that are run on the connector.
-
#connector_id ⇒ String
The unique ID of the connector.
-
#created_at ⇒ Time
The date and time that the connector was created.
-
#environment_id ⇒ String
The unique ID of the environment that the connector belongs to.
-
#modified_at ⇒ Time
The date and time that the connector was modified.
-
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
-
#state ⇒ String
The state of the connector.
-
#state_details ⇒ String
A detailed description of the connector state.
-
#status ⇒ String
The status of the connector.
-
#type ⇒ String
The type of the connector.
Instance Attribute Details
#appliance_fqdn ⇒ String
The fully qualified domain name (FQDN) of the VCF appliance that the connector connects to.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#checks ⇒ Array<Types::ConnectorCheck>
A list of checks that are run on the connector.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#connector_id ⇒ String
The unique ID of the connector.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time that the connector was created.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The unique ID of the environment that the connector belongs to.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time that the connector was modified.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the connector.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
A detailed description of the connector state.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the connector.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the connector.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-evs/types.rb', line 181 class Connector < Struct.new( :environment_id, :connector_id, :type, :appliance_fqdn, :secret_arn, :state, :state_details, :status, :checks, :created_at, :modified_at) SENSITIVE = [] include Aws::Structure end |