Class: Aws::Evs::Types::CreateEnvironmentConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::CreateEnvironmentConnectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#appliance_fqdn ⇒ String
The fully qualified domain name (FQDN) of the VCF appliance that the connector targets.
-
#client_token ⇒ String
This parameter is not used in Amazon EVS currently. -
#environment_id ⇒ String
A unique ID for the environment to create the connector in.
-
#secret_identifier ⇒ String
The ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
-
#type ⇒ String
The type of connector to create.
Instance Attribute Details
#appliance_fqdn ⇒ String
The fully qualified domain name (FQDN) of the VCF appliance that the connector targets.
362 363 364 365 366 367 368 369 370 |
# File 'lib/aws-sdk-evs/types.rb', line 362 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the connector creation request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
362 363 364 365 366 367 368 369 370 |
# File 'lib/aws-sdk-evs/types.rb', line 362 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
A unique ID for the environment to create the connector in.
362 363 364 365 366 367 368 369 370 |
# File 'lib/aws-sdk-evs/types.rb', line 362 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#secret_identifier ⇒ String
The ARN or name of the Amazon Web Services Secrets Manager secret
that stores the credentials for the VCF appliance. SDDC_MANAGER
requires an apiKey field; OPERATIONS_MANAGER and VCENTER
require username and password fields.
Do not use credentials with Administrator privileges. We recommend using a service account with read-only permissions.
362 363 364 365 366 367 368 369 370 |
# File 'lib/aws-sdk-evs/types.rb', line 362 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of connector to create.
-
OPERATIONS_MANAGER: Connector to an Operations Manager appliance. Required for VCF 9x environments. -
SDDC_MANAGER: Connector to an SDDC Manager appliance. Required for VCF 5.x environments. -
VCENTER: Connector to a vCenter Server appliance. Required for features that depend on vCenter, such as Windows Server license-included.
362 363 364 365 366 367 368 369 370 |
# File 'lib/aws-sdk-evs/types.rb', line 362 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |