Class: Aws::Evs::Types::CreateEnvironmentConnectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#appliance_fqdnString

The fully qualified domain name (FQDN) of the VCF appliance that the connector targets.

Returns:

  • (String)


322
323
324
325
326
327
328
329
330
# File 'lib/aws-sdk-evs/types.rb', line 322

class CreateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :type,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

<note markdown=“1”> This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.

</note>

A unique, case-sensitive identifier that you provide to ensure the

idempotency of the connector creation request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


322
323
324
325
326
327
328
329
330
# File 'lib/aws-sdk-evs/types.rb', line 322

class CreateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :type,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

A unique ID for the environment to create the connector in.

Returns:

  • (String)


322
323
324
325
326
327
328
329
330
# File 'lib/aws-sdk-evs/types.rb', line 322

class CreateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :type,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#secret_identifierString

The ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.

Do not use credentials with Administrator privileges. We recommend using a service account with the minimum required permissions.

Returns:

  • (String)


322
323
324
325
326
327
328
329
330
# File 'lib/aws-sdk-evs/types.rb', line 322

class CreateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :type,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of connector to create.

Returns:

  • (String)


322
323
324
325
326
327
328
329
330
# File 'lib/aws-sdk-evs/types.rb', line 322

class CreateEnvironmentConnectorRequest < Struct.new(
  :client_token,
  :environment_id,
  :type,
  :appliance_fqdn,
  :secret_identifier)
  SENSITIVE = []
  include Aws::Structure
end