Class: Aws::Evs::Types::CreateEnvironmentConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::CreateEnvironmentConnectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#appliance_fqdn ⇒ String
The fully qualified domain name (FQDN) of the VCF appliance that the connector targets.
-
#client_token ⇒ String
<note markdown=“1”> This parameter is not used in Amazon EVS currently.
-
#environment_id ⇒ String
A unique ID for the environment to create the connector in.
-
#secret_identifier ⇒ String
The ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
-
#type ⇒ String
The type of connector to create.
Instance Attribute Details
#appliance_fqdn ⇒ String
The fully qualified domain name (FQDN) of the VCF appliance that the connector targets.
322 323 324 325 326 327 328 329 330 |
# File 'lib/aws-sdk-evs/types.rb', line 322 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
<note markdown=“1”> This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.
</note>
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the connector creation request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
322 323 324 325 326 327 328 329 330 |
# File 'lib/aws-sdk-evs/types.rb', line 322 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
A unique ID for the environment to create the connector in.
322 323 324 325 326 327 328 329 330 |
# File 'lib/aws-sdk-evs/types.rb', line 322 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#secret_identifier ⇒ String
The ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
Do not use credentials with Administrator privileges. We recommend using a service account with the minimum required permissions.
322 323 324 325 326 327 328 329 330 |
# File 'lib/aws-sdk-evs/types.rb', line 322 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of connector to create.
322 323 324 325 326 327 328 329 330 |
# File 'lib/aws-sdk-evs/types.rb', line 322 class CreateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :type, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |