Class: Aws::Evs::Types::CreateEnvironmentHostRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-evs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

<note markdown=“1”> This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.

</note>

A unique, case-sensitive identifier that you provide to ensure the

idempotency of the host creation request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


374
375
376
377
378
379
380
381
# File 'lib/aws-sdk-evs/types.rb', line 374

class CreateEnvironmentHostRequest < Struct.new(
  :client_token,
  :environment_id,
  :host,
  :esx_version)
  SENSITIVE = []
  include Aws::Structure
end

#environment_idString

A unique ID for the environment that the host is added to.

Returns:

  • (String)


374
375
376
377
378
379
380
381
# File 'lib/aws-sdk-evs/types.rb', line 374

class CreateEnvironmentHostRequest < Struct.new(
  :client_token,
  :environment_id,
  :host,
  :esx_version)
  SENSITIVE = []
  include Aws::Structure
end

#esx_versionString

The ESX version to use for the host.

Returns:

  • (String)


374
375
376
377
378
379
380
381
# File 'lib/aws-sdk-evs/types.rb', line 374

class CreateEnvironmentHostRequest < Struct.new(
  :client_token,
  :environment_id,
  :host,
  :esx_version)
  SENSITIVE = []
  include Aws::Structure
end

#hostTypes::HostInfoForCreate

The host that is created and added to the environment.



374
375
376
377
378
379
380
381
# File 'lib/aws-sdk-evs/types.rb', line 374

class CreateEnvironmentHostRequest < Struct.new(
  :client_token,
  :environment_id,
  :host,
  :esx_version)
  SENSITIVE = []
  include Aws::Structure
end