Class: Aws::Evs::Types::Host
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::Host
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
An ESX host that runs on an Amazon EC2 bare metal instance. Four hosts are created in an Amazon EVS environment during environment creation. You can add hosts to an environment using the ‘CreateEnvironmentHost` operation. Amazon EVS supports 4-16 hosts per environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time that the host was created.
-
#dedicated_host_id ⇒ String
The unique ID of the Amazon EC2 Dedicated Host.
-
#ec2_instance_id ⇒ String
The unique ID of the EC2 instance that represents the host.
-
#host_name ⇒ String
The DNS hostname of the host.
-
#host_state ⇒ String
The state of the host.
-
#instance_type ⇒ String
The EC2 instance type of the host.
-
#ip_address ⇒ String
The IP address of the host.
-
#key_name ⇒ String
The name of the SSH key that is used to access the host.
-
#modified_at ⇒ Time
The date and time that the host was modified.
-
#network_interfaces ⇒ Array<Types::NetworkInterface>
The elastic network interfaces that are attached to the host.
-
#placement_group_id ⇒ String
The unique ID of the placement group where the host is placed.
-
#state_details ⇒ String
A detailed description of the ‘hostState` of a host.
Instance Attribute Details
#created_at ⇒ Time
The date and time that the host was created.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#dedicated_host_id ⇒ String
The unique ID of the Amazon EC2 Dedicated Host.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#ec2_instance_id ⇒ String
The unique ID of the EC2 instance that represents the host.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#host_name ⇒ String
The DNS hostname of the host. DNS hostnames for hosts must be unique across Amazon EVS environments and within VCF.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#host_state ⇒ String
The state of the host.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The EC2 instance type of the host.
<note markdown=“1”> Currently, Amazon EVS supports only the ‘i4i.metal` instance type.
</note>
<note markdown=“1”> EC2 instances created through Amazon EVS do not support associating an IAM instance profile.
</note>
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#ip_address ⇒ String
The IP address of the host.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#key_name ⇒ String
The name of the SSH key that is used to access the host.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time that the host was modified.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#network_interfaces ⇒ Array<Types::NetworkInterface>
The elastic network interfaces that are attached to the host.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#placement_group_id ⇒ String
The unique ID of the placement group where the host is placed.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |
#state_details ⇒ String
A detailed description of the ‘hostState` of a host.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 |
# File 'lib/aws-sdk-evs/types.rb', line 1208 class Host < Struct.new( :host_name, :ip_address, :key_name, :instance_type, :placement_group_id, :dedicated_host_id, :created_at, :modified_at, :host_state, :state_details, :ec2_instance_id, :network_interfaces) SENSITIVE = [] include Aws::Structure end |