Class: Aws::Evs::Types::NetworkInterface
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::NetworkInterface
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
An elastic network interface (ENI) that connects hosts to the VLAN subnets. Amazon EVS provisions two identically configured ENIs in the VMkernel management subnet during host creation. One ENI is active, and the other is in standby mode for automatic switchover during a failure scenario.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#network_interface_id ⇒ String
The unique ID of the elastic network interface.
Instance Attribute Details
#network_interface_id ⇒ String
The unique ID of the elastic network interface.
1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-evs/types.rb', line 1743 class NetworkInterface < Struct.new( :network_interface_id) SENSITIVE = [] include Aws::Structure end |