Class: Aws::Evs::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
The operation could not be performed because the service is throttling requests. This exception is thrown when the service endpoint receives too many concurrent requests.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Describes the error encountered.
-
#retry_after_seconds ⇒ Integer
The seconds to wait to retry.
Instance Attribute Details
#message ⇒ String
Describes the error encountered.
1900 1901 1902 1903 1904 1905 |
# File 'lib/aws-sdk-evs/types.rb', line 1900 class ThrottlingException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ Integer
The seconds to wait to retry.
1900 1901 1902 1903 1904 1905 |
# File 'lib/aws-sdk-evs/types.rb', line 1900 class ThrottlingException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |