Class: Aws::Evs::Types::UpdateEnvironmentConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::UpdateEnvironmentConnectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#appliance_fqdn ⇒ String
The new fully qualified domain name (FQDN) of the VCF appliance that the connector connects to.
-
#client_token ⇒ String
<note markdown=“1”> This parameter is not used in Amazon EVS currently.
-
#connector_id ⇒ String
A unique ID for the connector to update.
-
#environment_id ⇒ String
A unique ID for the environment that the connector belongs to.
-
#secret_identifier ⇒ String
The new ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
Instance Attribute Details
#appliance_fqdn ⇒ String
The new fully qualified domain name (FQDN) of the VCF appliance that the connector connects to.
1996 1997 1998 1999 2000 2001 2002 2003 2004 |
# File 'lib/aws-sdk-evs/types.rb', line 1996 class UpdateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :connector_id, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
<note markdown=“1”> This parameter is not used in Amazon EVS currently. If you supply input for this parameter, it will have no effect.
</note>
A unique, case-sensitive identifier that you provide to ensure the
idempotency of the connector update request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1996 1997 1998 1999 2000 2001 2002 2003 2004 |
# File 'lib/aws-sdk-evs/types.rb', line 1996 class UpdateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :connector_id, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#connector_id ⇒ String
A unique ID for the connector to update.
1996 1997 1998 1999 2000 2001 2002 2003 2004 |
# File 'lib/aws-sdk-evs/types.rb', line 1996 class UpdateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :connector_id, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
A unique ID for the environment that the connector belongs to.
1996 1997 1998 1999 2000 2001 2002 2003 2004 |
# File 'lib/aws-sdk-evs/types.rb', line 1996 class UpdateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :connector_id, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |
#secret_identifier ⇒ String
The new ARN or name of the Amazon Web Services Secrets Manager secret that stores the credentials for the VCF appliance.
1996 1997 1998 1999 2000 2001 2002 2003 2004 |
# File 'lib/aws-sdk-evs/types.rb', line 1996 class UpdateEnvironmentConnectorRequest < Struct.new( :client_token, :environment_id, :connector_id, :appliance_fqdn, :secret_identifier) SENSITIVE = [] include Aws::Structure end |