Class: Aws::Evs::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
The input fails to satisfy the specified constraints. You will see this exception if invalid inputs are provided for any of the Amazon EVS environment operations, or if a list operation is performed on an environment resource that is still initializing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_list ⇒ Array<Types::ValidationExceptionField>
A list of fields that didn’t validate.
-
#message ⇒ String
Describes the error encountered.
-
#reason ⇒ String
The reason for the exception.
Instance Attribute Details
#field_list ⇒ Array<Types::ValidationExceptionField>
A list of fields that didn’t validate.
2029 2030 2031 2032 2033 2034 2035 |
# File 'lib/aws-sdk-evs/types.rb', line 2029 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
Describes the error encountered.
2029 2030 2031 2032 2033 2034 2035 |
# File 'lib/aws-sdk-evs/types.rb', line 2029 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason for the exception.
2029 2030 2031 2032 2033 2034 2035 |
# File 'lib/aws-sdk-evs/types.rb', line 2029 class ValidationException < Struct.new( :message, :reason, :field_list) SENSITIVE = [] include Aws::Structure end |