Class: Aws::Evs::Types::VmEntitlement
- Inherits:
-
Struct
- Object
- Struct
- Aws::Evs::Types::VmEntitlement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-evs/types.rb
Overview
An object that represents a Windows Server License entitlement for a virtual machine in an Amazon EVS environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_id ⇒ String
The unique ID of the connector associated with the entitlement.
-
#environment_id ⇒ String
The unique ID of the environment.
-
#error_detail ⇒ Types::ErrorDetail
The error details associated with the entitlement, if applicable.
-
#last_synced_at ⇒ Time
The date and time that the entitlement was last synced.
-
#started_at ⇒ Time
The date and time that the entitlement started.
-
#status ⇒ String
The status of the entitlement.
-
#stopped_at ⇒ Time
The date and time that the entitlement stopped.
-
#type ⇒ String
The type of entitlement.
-
#vm_id ⇒ String
The unique ID of the virtual machine.
-
#vm_name ⇒ String
The name of the virtual machine.
Instance Attribute Details
#connector_id ⇒ String
The unique ID of the connector associated with the entitlement.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#environment_id ⇒ String
The unique ID of the environment.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#error_detail ⇒ Types::ErrorDetail
The error details associated with the entitlement, if applicable.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#last_synced_at ⇒ Time
The date and time that the entitlement was last synced.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time that the entitlement started.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the entitlement.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#stopped_at ⇒ Time
The date and time that the entitlement stopped.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of entitlement.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#vm_id ⇒ String
The unique ID of the virtual machine.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |
#vm_name ⇒ String
The name of the virtual machine.
2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 |
# File 'lib/aws-sdk-evs/types.rb', line 2281 class VmEntitlement < Struct.new( :vm_id, :environment_id, :connector_id, :vm_name, :type, :status, :last_synced_at, :started_at, :stopped_at, :error_detail) SENSITIVE = [] include Aws::Structure end |